package com.seeyon.apps.govdoc.option.util;

import com.seeyon.ctp.common.log.CtpLogFactory;
import com.seeyon.apps.govdoc.po.FormOptionExtend;
import com.seeyon.ctp.form.bean.FormBean;
import com.seeyon.ctp.form.bean.FormFieldBean;
import com.seeyon.ctp.common.ModuleType;
import com.seeyon.apps.govdoc.manager.GovdocCommentManager;
import com.seeyon.apps.govdoc.option.manager.FormOptionSortManager;
import com.seeyon.apps.govdoc.option.manager.FormOptionExtendManager;
import com.seeyon.ctp.form.api.FormApi4Cap3;
import com.seeyon.v3x.edoc.domain.EdocSummary;
import java.io.IOException;
import java.io.OutputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import com.seeyon.ctp.common.file.model.CtpLocalFile;
import com.seeyon.ctp.common.constants.SystemProperties;
import com.seeyon.v3x.system.signet.manager.SignetManager;
import com.seeyon.ctp.common.content.affair.constants.StateEnum;
import org.apache.commons.beanutils.BeanUtils;
import com.seeyon.v3x.edoc.webmodel.EdocOpinionBO;
import com.seeyon.ctp.common.content.affair.constants.SubStateEnum;
import com.seeyon.ctp.common.affair.manager.AffairManager;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import com.seeyon.ctp.common.filemanager.manager.Util;
import com.seeyon.ctp.util.json.JSONUtil;
import com.seeyon.apps.govdoc.helper.GovdocHelper;
import java.sql.Timestamp;
import java.util.Objects;
import java.util.Date;
import com.seeyon.ctp.util.Datetimes;
import java.util.Set;
import java.util.stream.Collector;
import java.util.stream.Collectors;
import java.util.function.Function;
import com.seeyon.apps.govdoc.pishi.po.EdocLeaderPishiNo;
import com.seeyon.ctp.common.po.filemanager.Attachment;
import java.util.HashMap;
import com.seeyon.apps.govdoc.pishi.manager.GovdocPishiManager;
import com.seeyon.ctp.common.filemanager.manager.AttachmentManager;
import com.seeyon.apps.govdoc.manager.GovdocOpenManager;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.common.content.comment.Comment;
import com.seeyon.ctp.common.po.affair.CtpAffair;
import com.seeyon.v3x.edoc.webmodel.EdocOpinionModel;
import java.util.Map;
import com.seeyon.ctp.common.authenticate.domain.User;
import java.util.Iterator;
import java.util.List;
import com.seeyon.ctp.organization.bo.V3xOrgMember;
import com.seeyon.ctp.common.i18n.ResourceBundleUtil;
import com.seeyon.ctp.common.SystemEnvironment;
import com.thoughtworks.xstream.core.util.Base64Encoder;
import com.seeyon.ctp.form.util.FormUtil;
import com.seeyon.v3x.system.signet.domain.V3xSignet;
import com.seeyon.apps.govdoc.manager.GovdocSignetManager;
import java.util.Collection;
import com.seeyon.v3x.system.signet.domain.V3xHtmDocumentSignature;
import java.util.ArrayList;
import com.seeyon.v3x.system.signet.enums.V3xHtmSignatureEnum;
import com.seeyon.ctp.util.FlipInfo;
import com.seeyon.v3x.system.signet.manager.V3xHtmDocumentSignatManager;
import com.seeyon.v3x.edoc.constants.EdocOpinionDisplayEnum;
import com.seeyon.v3x.edoc.webmodel.FormOpinionConfig;
import com.seeyon.ctp.organization.manager.OrgManager;
import com.seeyon.v3x.edoc.util.Constants;
import com.seeyon.ctp.common.i18n.ResourceUtil;
import com.seeyon.ctp.util.Strings;
import com.seeyon.ctp.common.ctpenumnew.EnumNameEnum;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.ctpenumnew.manager.EnumManager;
import com.seeyon.v3x.edoc.domain.EdocOpinion;
import org.apache.commons.logging.Log;

public class EdocOptionDisplayUtil
{
    private static final Log LOGGER;
    
    private static String getAttitude(final Integer opinionType, final int attitude) {
        String attitudeStr = null;
        String attitudeI18nLabel = "";
        if (attitude > 0) {
            if (EdocOpinion.OpinionType.backOpinion.ordinal() == opinionType) {
                attitudeI18nLabel = "stepBack.label";
            }
            else if (EdocOpinion.OpinionType.stopOpinion.ordinal() == opinionType) {
                attitudeI18nLabel = "stepStop.label";
            }
            else if (EdocOpinion.OpinionType.repealOpinion.ordinal() == opinionType) {
                attitudeI18nLabel = "edoc.repeal.2.label";
            }
            else {
                final EnumManager enumManager = (EnumManager)AppContext.getBean("enumManagerNew");
                attitudeI18nLabel = enumManager.getEnumItemLabel(EnumNameEnum.collaboration_attitude, Integer.toString(attitude));
            }
        }
        if (Strings.isNotBlank(attitudeI18nLabel)) {
            attitudeStr = ResourceUtil.getString(attitudeI18nLabel);
        }
        else if (attitude == Constants.EDOC_ATTITUDE_NULL) {
            attitudeStr = null;
        }
        if (opinionType == EdocOpinion.OpinionType.senderOpinion.ordinal()) {
            attitudeStr = null;
        }
        return attitudeStr;
    }
    
    private static String getOpinionUserName(final Long userId, final String proxyName, final OrgManager orgManager, final FormOpinionConfig displayConfig, final EdocOpinion edocOpinion, final boolean popUserInfo, final boolean hasSign) {
        String doUserName = "";
        try {
            final V3xOrgMember member = orgManager.getMemberById(userId);
            final Long MainAccountId = member.getOrgAccountId();
            doUserName = member.getName();
            final String postInfo = edocOpinion.getPostInfo();
            Long currentAccountId = null;
            if (Strings.isNotBlank(postInfo)) {
                final String[] postInfos = postInfo.split("\\|");
                if (postInfos.length > 2) {
                    final String accountIdStringType = postInfos[0];
                    currentAccountId = Long.parseLong(accountIdStringType);
                }
            }
            if (currentAccountId == null) {
                currentAccountId = member.getOrgAccountId();
            }
            if (edocOpinion.isBound() && EdocOpinionDisplayEnum.OpinionShowNameTypeEnum.SIGN.getValue().equals(displayConfig.getShowNameType())) {
                final V3xHtmDocumentSignatManager v3xHtmDocumentSignatManager = (V3xHtmDocumentSignatManager)AppContext.getBean("v3xHtmDocumentSignatManager");
                final FlipInfo flipInfo = new FlipInfo(-1, -1);
                flipInfo.setNeedTotal(false);
                final List<V3xHtmDocumentSignature> signs = v3xHtmDocumentSignatManager.findBySummaryIdAndType(edocOpinion.getEdocId(), V3xHtmSignatureEnum.HTML_SIGNATURE_EDOC_FLOW_INSCRIBE.getKey(), flipInfo);
                final List<V3xHtmDocumentSignature> signatureList = new ArrayList<V3xHtmDocumentSignature>();
                if (Strings.isNotEmpty((Collection)signs)) {
                    for (final V3xHtmDocumentSignature sign : signs) {
                        if (sign.getAffairId() != null && edocOpinion.getAffairId() == sign.getAffairId()) {
                            signatureList.add(sign);
                        }
                    }
                }
                if (Strings.isNotEmpty((Collection)signatureList)) {
                    final GovdocSignetManager govdocSignetManager = (GovdocSignetManager)AppContext.getBean("govdocSignetManager");
                    final List<V3xSignet> signetList = govdocSignetManager.findSignetByMemberId(Long.valueOf(edocOpinion.getCreateUserId()));
                    V3xSignet MainV3xSignet = null;
                    V3xSignet v3xSignet = null;
                    if (signetList != null && !signetList.isEmpty()) {
                        final Integer signType = 0;
                        for (final V3xSignet signTemp : signetList) {
                            if (signType.equals(signTemp.getMarkType())) {
                                if (currentAccountId == null) {
                                    EdocOptionDisplayUtil.LOGGER.warn((Object)String.format("未找到%s的单位id，随机取一个签名", userId));
                                    v3xSignet = signTemp;
                                    break;
                                }
                                if (signTemp.getOrgAccountId() == (long)currentAccountId) {
                                    v3xSignet = signTemp;
                                }
                                else {
                                    if (signTemp.getOrgAccountId() != (long)MainAccountId) {
                                        continue;
                                    }
                                    MainV3xSignet = signTemp;
                                }
                            }
                        }
                    }
                    if (v3xSignet == null && MainV3xSignet != null) {
                        v3xSignet = MainV3xSignet;
                    }
                    if (v3xSignet != null) {
                        String imgStr = "";
                        if (FormUtil.isPhoneLogin() || FormUtil.isH5()) {
                            if (v3xSignet.getMarkBodyByte() != null) {
                                final Base64Encoder encoder = new Base64Encoder();
                                imgStr = encoder.encode(v3xSignet.getMarkBodyByte());
                                imgStr = imgStr.replaceAll("\r\n", "").replace("\\", "");
                                imgStr = imgStr.replaceAll("\n", "");
                                final String C_sPicDataFormat_Gif = "data:image/gif;base64,";
                                final String C_sPicDataFormat_Png = "data:image/png;base64,";
                                final String C_sPicDataFormat_Jpeg = "data:image/jpeg;base64,";
                                if (imgStr.indexOf("iVBO") == 0) {
                                    imgStr = C_sPicDataFormat_Png + imgStr;
                                }
                                else if (imgStr.indexOf("R0lG") == 0) {
                                    imgStr = C_sPicDataFormat_Gif + imgStr;
                                }
                                else {
                                    imgStr = C_sPicDataFormat_Jpeg + imgStr;
                                }
                            }
                        }
                        else {
                            imgStr = SystemEnvironment.getContextPath() + "/edocController.do?method=showInscribeSignetPic&id=" + v3xSignet.getId();
                        }
                        doUserName = "<IMG alt=\"" + Strings.toHTML(doUserName) + "\" style=\"pointer-events: none;vertical-align: text-bottom;max-width:100%;\" src=\"" + imgStr + "\" >";
                    }
                    else {
                        EdocOptionDisplayUtil.LOGGER.warn((Object)String.format("未找到%s的签名！", userId));
                    }
                }
            }
            final User user = AppContext.getCurrentUser();
            if (member.getIsAdmin()) {
                doUserName = "<span> " + doUserName + "</span>";
            }
            else if (popUserInfo && "pc".equals(user.getUserAgentFrom())) {
                doUserName = "<span style='color:#2490f8; display:inline-block;cursor:pointer;' onclick='javascript:showV3XMemberCard(\"" + userId + "\",parent.window)'>" + doUserName + "</span>";
            }
            if (FormUtil.isPhoneLogin() && displayConfig.isHideInscriber() && hasSign) {
                doUserName = "";
            }
            if (!Strings.isBlank(proxyName) && !proxyName.equals(member.getName())) {
                doUserName += ResourceBundleUtil.getString("com.seeyon.v3x.edoc.resources.i18n.EdocResource", "edoc.opinion.proxy", new Object[] { proxyName });
            }
        }
        catch (final Exception e) {
            EdocOptionDisplayUtil.LOGGER.error((Object)"取公文单显示的时候的人名 抛出异常", (Throwable)e);
        }
        return doUserName;
    }
    
    public static byte[] hex2byte(String str) {
        if (str == null) {
            return null;
        }
        str = str.trim();
        final int len = str.length();
        if (len == 0 || len % 2 == 1) {
            return null;
        }
        final byte[] b = new byte[len / 2];
        try {
            for (int i = 0; i < str.length(); i += 2) {
                b[i / 2] = (byte)(int)Integer.decode("0X" + str.substring(i, i + 2));
            }
            return b;
        }
        catch (final Exception e) {
            EdocOptionDisplayUtil.LOGGER.error((Object)"", (Throwable)e);
            return null;
        }
    }
    
    public static Map<String, Object> convertOpinionToString(final Map<String, EdocOpinionModel> map, final FormOpinionConfig displayConfig, final CtpAffair currentAffair, final boolean isFromPending, final List<V3xHtmDocumentSignature> signatuers, final List<Comment> commentList) throws BusinessException {
        return convertOpinionToString(map, displayConfig, signatuers, commentList);
    }
    
    public static Map<String, Object> convertOpinionToString(final Map<String, EdocOpinionModel> map, final FormOpinionConfig displayConfig, final List<V3xHtmDocumentSignature> signatuers, final List<Comment> commentList) throws BusinessException {
        final GovdocOpenManager govdocOpenManager = (GovdocOpenManager)AppContext.getBean("govdocOpenManager");
        final AttachmentManager attachmentManager = (AttachmentManager)AppContext.getBean("attachmentManager");
        final GovdocPishiManager govdocPishiManager = (GovdocPishiManager)AppContext.getBean("govdocPishiManager");
        final boolean hasEdit = govdocOpenManager.hasEditAuth(Long.valueOf(AppContext.currentUserId()), Long.valueOf(AppContext.currentAccountId()));
        final boolean synCommentInForm = govdocOpenManager.isSynCommentInForm();
        final Map<Long, StringBuilder> senderAttMap = new HashMap<Long, StringBuilder>();
        final List<EdocOpinion> senderOpinions = new ArrayList<EdocOpinion>();
        final List<Attachment> commentAttachments = new ArrayList<Attachment>();
        final int backOpinonType = displayConfig.getBackOpinionType();
        final Map<Long, List<Comment>> commentMap = new HashMap<Long, List<Comment>>();
        final Map<Long, Comment> affairIdToCommentMap = new HashMap<Long, Comment>();
        Map<Long, EdocLeaderPishiNo> affairIdToPishiNoMap = new HashMap<Long, EdocLeaderPishiNo>();
        if (Strings.isNotEmpty((Collection)commentList)) {
            affairIdToPishiNoMap = govdocPishiManager.getPishiNoMapByAffairId((Collection)commentList.stream().map((Function<? super Object, ?>)Comment::getAffairId).collect((Collector<? super Object, ?, Set<? super Object>>)Collectors.toSet()));
            for (final Comment comment : commentList) {
                List<Comment> comments = new ArrayList<Comment>();
                if (Strings.isNotEmpty((Collection)commentMap.get(comment.getAffairId()))) {
                    comments = commentMap.get(comment.getAffairId());
                }
                if (backOpinonType == 1 && "common.toolbar.stepBack.label".equals(comment.getExtAtt3())) {
                    continue;
                }
                if (!"common.save.and.pause.flow".equals(comment.getExtAtt3()) && comment.getCtype() != null && comment.getCtype() == Comment.CommentType.comment.getKey()) {
                    if (affairIdToCommentMap.get(comment.getAffairId()) != null) {
                        EdocOptionDisplayUtil.LOGGER.error((Object)("获取comment错误。affairId 相同存在两条非暂存代办的评论！commentId= " + comment.getId()));
                    }
                    affairIdToCommentMap.put(comment.getAffairId(), comment);
                }
                comments.add(comment);
                commentMap.put(comment.getAffairId(), comments);
            }
        }
        final Map<String, Object> jsMap = new HashMap<String, Object>();
        String fileUrlStr = "";
        final OrgManager orgManager = (OrgManager)AppContext.getBean("orgManager");
        for (final String element : map.keySet()) {
            final EdocOpinionModel model = map.get(element);
            final List<EdocOpinion> opinions = model.getOpinions();
            final boolean showZcdb = !FormOpinionConfig.checkBoolean(displayConfig.getZcdbOptionType());
            for (final EdocOpinion opinion : opinions) {
                if (opinion.getOpinionType() != EdocOpinion.OpinionType.provisionalOpinoin.ordinal() || showZcdb) {
                    if (opinion.getOpinionType() == EdocOpinion.OpinionType.draftOpinion.ordinal()) {
                        continue;
                    }
                    final boolean showEditAndDelButton = !synCommentInForm && hasEdit && opinion.getOpinionType() != EdocOpinion.OpinionType.provisionalOpinoin.ordinal() && !FormUtil.isPhoneLogin();
                    final StringBuilder sb = new StringBuilder();
                    final String value = jsMap.get(element);
                    if (value != null) {
                        sb.append(value);
                    }
                    boolean hasSignature = false;
                    if (signatuers != null && signatuers.size() > 0) {
                        for (final V3xHtmDocumentSignature signature : signatuers) {
                            if (signature != null && null != signature.getAffairId() && signature.getAffairId().equals(opinion.getAffairId())) {
                                hasSignature = true;
                            }
                        }
                    }
                    String attitude = "";
                    String tempAttitude = "";
                    switch (opinion.getAttribute()) {
                        case 1: {
                            tempAttitude = "haveRead";
                            break;
                        }
                        case 2: {
                            tempAttitude = "agree";
                            break;
                        }
                        case 3: {
                            tempAttitude = "disagree";
                            break;
                        }
                    }
                    Comment comment2 = null;
                    final List<Comment> comments2 = commentMap.get(opinion.getAffairId());
                    if (Strings.isNotEmpty((Collection)comments2)) {
                        if (comments2.size() == 1) {
                            comment2 = comments2.get(0);
                        }
                        else {
                            for (final Comment tempComment : comments2) {
                                if (tempComment.getCreateDate().equals(opinion.getCreateTime())) {
                                    comment2 = tempComment;
                                    break;
                                }
                            }
                            if (comment2 == null) {
                                final Date beforeTwoSecond = Datetimes.addSecond((Date)opinion.getCreateTime(), -3);
                                final Date afterTwoSecond = Datetimes.addSecond((Date)opinion.getCreateTime(), 3);
                                for (final Comment tempComment2 : comments2) {
                                    if (Datetimes.between(tempComment2.getCreateDate(), beforeTwoSecond, afterTwoSecond, false)) {
                                        comment2 = tempComment2;
                                        break;
                                    }
                                }
                            }
                            if (comment2 == null) {
                                comment2 = comments2.get(0);
                            }
                        }
                    }
                    if (comment2 != null) {
                        if (tempAttitude.equals((comment2.getExtAtt4() == null) ? "" : comment2.getExtAtt4())) {
                            attitude = comment2.getExtAtt1I18n();
                        }
                        if (Strings.isNotBlank(comment2.getExtAtt1())) {
                            attitude = comment2.getExtAtt1I18n();
                        }
                        if (Objects.nonNull(comment2.getCreateDate())) {
                            opinion.setCreateTime(new Timestamp(comment2.getCreateDate().getTime()));
                        }
                    }
                    if (Strings.isBlank(attitude) && !Strings.isBlank(tempAttitude)) {
                        attitude = ResourceUtil.getString("collaboration.dealAttitude." + tempAttitude);
                    }
                    sb.append(displayOpinionContent(displayConfig, opinion, hasSignature, true, attitude));
                    List<Attachment> tempAtts = null;
                    if (null != opinion.getPolicy() && opinion.getPolicy().equals("feedback")) {
                        final Long subOpinionId = opinion.getSubOpinionId();
                        if (subOpinionId != null) {
                            tempAtts = GovdocHelper.getOpinionAttachmentsNotRelationDoc((long)opinion.getSubEdocId(), (long)subOpinionId);
                        }
                    }
                    else {
                        tempAtts = opinion.getOpinionAttachments();
                    }
                    if (tempAtts != null && displayConfig.isShowAtt()) {
                        final StringBuilder attSb = new StringBuilder();
                        sb.append("<br/>");
                        attSb.append("<div style='clear:both;'>");
                        for (final Attachment att : tempAtts) {
                            fileUrlStr = fileUrlStr + att.getFileUrl() + ",";
                            String s = "";
                            String attJson = JSONUtil.toJSONString((Object)att);
                            final Map<String, Object> maps = (Map<String, Object>)JSONUtil.parseJSONString(attJson);
                            maps.put("command", "131");
                            maps.put("name", att.getFilename());
                            attJson = JSONUtil.toJSONString((Object)maps);
                            final String attType = (maps.get("icon") != null) ? maps.get("icon").toString() : "";
                            String miniType = "";
                            if (!"".equals(attType) && attType.contains(".")) {
                                miniType = attType.split("\\.")[0];
                            }
                            if (FormUtil.isPhoneLogin() || FormUtil.isH5()) {
                                String iconClass = "";
                                if (Strings.isNotBlank(miniType)) {
                                    iconClass = getIconClass(miniType);
                                }
                                final String icon = "<i class='attachment-icon " + iconClass + "'></i>";
                                s = "<div style='display:block'>" + icon + "<a class='document-content allow-click-attachment' style='text-decoration:underline;margin-left:10px;font-size:12px;color:#005599' see-att-data = '" + attJson + "'>" + att.getFilename() + "</a></div>";
                            }
                            else {
                                final String imageStr = "<span style=\"word-wrap:break-word; word-break:break-all;position:relative;top:-1px;\" class=\"ico16 " + miniType + "_16 margin_r_5\"></span>";
                                String str = Util.AttachmentToHtmlWithShowAllFileName(att, true, false);
                                if (StringUtils.isNotEmpty(att.getSecretLevelName())) {
                                    String old = Strings.toHTML(att.getFilename()) + "(";
                                    final StringBuffer newT = new StringBuffer();
                                    if (att.getType() == com.seeyon.ctp.common.filemanager.Constants.ATTACHMENT_TYPE.DOCUMENT.ordinal()) {
                                        old = ">" + Strings.toHTML(att.getFilename()) + "<";
                                        newT.append("><span style=\"color:#FF4141\">[" + att.getSecretLevelName() + "]</span>").append(Strings.toHTML(att.getFilename())).append("<").toString();
                                    }
                                    else {
                                        newT.append("<span style=\"color:#FF4141\">[" + att.getSecretLevelName() + "]</span>").append(Strings.toHTML(att.getFilename())).append("(").toString();
                                    }
                                    str = str.replace(old, newT.toString());
                                }
                                final int imgBegin = str.indexOf("<img");
                                s = str.substring(0, imgBegin) + imageStr + str.substring(str.indexOf("<", imgBegin + 4), str.length());
                            }
                            sb.append(s);
                            attSb.append(s);
                        }
                        attSb.append("</div>");
                        if ("senderOpinion".equals(element)) {
                            senderAttMap.put(opinion.getId(), attSb);
                        }
                    }
                    if (showEditAndDelButton) {
                        final Comment opinionToComment = affairIdToCommentMap.get(opinion.getAffairId());
                        final EdocLeaderPishiNo edocLeaderPishiNo = affairIdToPishiNoMap.get(opinion.getAffairId());
                        if (opinionToComment != null) {
                            sb.append(displayEditAndDelButton(opinionToComment.getId(), opinion, edocLeaderPishiNo));
                            sb.append("<br/>");
                        }
                    }
                    if ("senderOpinion".equals(element)) {
                        senderOpinions.add(opinion);
                    }
                    else {
                        if (tempAtts == null || !displayConfig.isShowAtt()) {
                            sb.append("<br/>");
                        }
                        jsMap.put(element, sb.toString());
                    }
                }
            }
        }
        if (Strings.isNotBlank(fileUrlStr) && fileUrlStr.length() > 1) {
            fileUrlStr = fileUrlStr.substring(0, fileUrlStr.length() - 1);
        }
        for (final Comment comment3 : affairIdToCommentMap.values()) {
            final List<Attachment> commentAtts = attachmentManager.getByReference(comment3.getModuleId(), comment3.getId());
            if (CollectionUtils.isNotEmpty((Collection)commentAtts)) {
                commentAttachments.addAll(commentAtts);
            }
        }
        AppContext.putRequestContext("fileUrlStr", (Object)fileUrlStr);
        jsMap.put("senderOpinionAttStr", senderAttMap);
        jsMap.put("senderOpinionList", senderOpinions);
        jsMap.put("commentAttachments", commentAttachments);
        return jsMap;
    }
    
    private static String displayEditAndDelButton(final Long commentId, final EdocOpinion opinion, final EdocLeaderPishiNo edocLeaderPishiNo) {
        String edocLeaderPishiStr = "";
        if (edocLeaderPishiNo != null) {
            final StringBuilder sb = new StringBuilder();
            final String pishiName = edocLeaderPishiNo.getPishiName();
            final Integer pishiNo = edocLeaderPishiNo.getPishiNo();
            final String pishiYear = edocLeaderPishiNo.getPishiYear();
            final Date proxyDate = edocLeaderPishiNo.getProxyDate();
            final String proxyDateShow = Datetimes.formatDate(edocLeaderPishiNo.getProxyDate());
            sb.append("hasPishi=\"true\"");
            sb.append("pishiName=\"" + pishiName + "\"");
            sb.append("pishiNo=\"" + pishiNo + "\"");
            sb.append("pishiYear=\"" + pishiYear + "\"");
            sb.append("proxyDate=\"" + proxyDate + "\"");
            sb.append("proxyDateShow=\"" + proxyDateShow + "\"");
            edocLeaderPishiStr = Strings.toText(sb.toString());
        }
        final String content = Strings.toHTML(opinion.getContent());
        final String opinionId = opinion.getId().toString();
        final Long affairId = opinion.getAffairId();
        return "<a " + edocLeaderPishiStr + " class=\"formPrintHide\"  onclick=\"openEditWindow(this)\" affairId=\"" + affairId + "\" content=\"" + content + "\" commentId=\"" + commentId + "\"  opinionId=\"" + opinionId + "\"  >" + ResourceUtil.getString("common.operate.edit") + "</a>&nbsp&nbsp<a   class=\"formPrintHide\"  onclick=\"delComment('" + commentId + "')\" >" + ResourceUtil.getString("common.toolbar.delete.label") + "</a>";
    }
    
    private static String replaceStr2Blank(final String src, final String defualt) {
        final StringBuilder ret = new StringBuilder();
        if (Strings.isBlank(src) && defualt != null) {
            ret.append(defualt);
        }
        else {
            for (int i = 0; i < src.length(); ++i) {
                final char c = src.charAt(i);
                if (c > '\0' && c < 'ÿ') {
                    ret.append(ResourceUtil.getString("govdoc.space"));
                }
                else {
                    ret.append(ResourceUtil.getString("govdoc.space.quan"));
                }
            }
        }
        return ret.toString();
    }
    
    private static String displayOpinionContent(final FormOpinionConfig displayConfig, final EdocOpinion opinion, final boolean hasSignature, final boolean popUserInfo, final String attitude) {
        final OrgManager orgManager = (OrgManager)AppContext.getBean("orgManager");
        final StringBuilder sb = new StringBuilder();
        String attribute = attitude;
        final String userName = getOpinionUserName(opinion.getCreateUserId(), opinion.getProxyName(), orgManager, displayConfig, opinion, popUserInfo, hasSignature);
        String content = opinion.getContent();
        String divId = String.valueOf(opinion.getAffairId());
        if (opinion.getOpinionType() == EdocOpinion.OpinionType.provisionalOpinoin.ordinal()) {
            divId += "_zc";
        }
        sb.append("<div id='" + divId + "' class='edocOpinion' style='clear:both;'>");
        sb.append("</div>");
        final boolean newLine = displayConfig.isInscriberNewLine();
        if (newLine) {
            sb.append("<span>");
        }
        if (!FormOpinionConfig.checkBoolean(displayConfig.getAttitude())) {
            attribute = "";
        }
        if (!FormOpinionConfig.checkBoolean(displayConfig.getComment())) {
            content = "";
        }
        final String blankString = "";
        String attrStr = null;
        if (Strings.isNotBlank(attribute) && attribute != null && null != opinion.getPolicy() && !opinion.getPolicy().equals("report")) {
            attrStr = "【" + attribute + "】";
            sb.append(attrStr);
        }
        sb.append(Strings.toHTML(content));
        if (newLine) {
            sb.append("</span><br/>");
        }
        final boolean alignRight = FormOpinionConfig.checkBoolean(displayConfig.getInscriberRight());
        if (newLine) {
            if (alignRight) {
                sb.append("<span style='text-align: right;width: 100%;display: inline-block; font-size: inherit;font-weight: inherit;font-style: inherit;'>");
            }
            else {
                sb.append("<span>");
                sb.append(blankString);
            }
        }
        else if (Strings.isNotBlank(content) && (displayConfig.isShowDept() || displayConfig.isShowUnit())) {
            sb.append("&ensp;&ensp;");
        }
        boolean isDisplay = true;
        if (displayConfig.isHideInscriber()) {
            final AffairManager affairManager = (AffairManager)AppContext.getBean("affairManager");
            CtpAffair affair = null;
            try {
                affair = affairManager.get(Long.valueOf(opinion.getAffairId()));
                if (affair != null && affair.getSubState() == SubStateEnum.col_done_stepStop.key()) {
                    isDisplay = false;
                }
            }
            catch (final BusinessException e) {
                EdocOptionDisplayUtil.LOGGER.error((Object)"获取affair错误", (Throwable)e);
            }
        }
        if (displayConfig.isShowUnit() && (!displayConfig.isHideInscriber() || !hasSignature) && isDisplay) {
            if (userName.indexOf("IMG") != -1 || newLine) {
                sb.append(opinion.getAccountName());
            }
            else {
                sb.append("&ensp;").append(opinion.getAccountName());
            }
        }
        if (displayConfig.isShowDept() && (!displayConfig.isHideInscriber() || !hasSignature) && isDisplay) {
            if ((userName.indexOf("IMG") != -1 || newLine) && !displayConfig.isShowUnit()) {
                sb.append(opinion.getDepartmentName());
            }
            else {
                sb.append("&ensp;").append(opinion.getDepartmentName());
            }
        }
        if (displayConfig.isShowName() && (!displayConfig.isHideInscriber() || !hasSignature) && isDisplay) {
            sb.append("&ensp;").append(userName);
        }
        String dateStr = "";
        if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATETIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                final Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format"));
            }
            else {
                dateStr = Datetimes.formatDatetimeWithoutSecond((Date)opinion.getCreateTime());
            }
        }
        else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATE.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                final Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format1"));
            }
            else {
                dateStr = Datetimes.formatDate((Date)opinion.getCreateTime());
            }
        }
        else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.TIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                final Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format3"));
            }
            else {
                dateStr = Datetimes.format((Date)opinion.getCreateTime(), " HH:mm");
            }
        }
        boolean dateNewLine = false;
        if (Strings.isNotBlank(dateStr)) {
            dateNewLine = FormOpinionConfig.checkBoolean(displayConfig.getDateNewLine());
            if (dateNewLine) {
                String styleText = "";
                if (alignRight) {
                    styleText = "text-align: right;width: 100%;display: inline-block;font-size: inherit;font-weight: inherit;font-style: inherit;";
                }
                if (newLine) {
                    sb.append("</span>");
                    sb.append("<br/>");
                    sb.append("<span style='color:black;display:block;" + styleText + "'>");
                    if (!alignRight) {
                        sb.append("");
                    }
                    sb.append(dateStr);
                }
                else {
                    sb.append("<br/>");
                    sb.append("<span style='display:block;" + styleText + "'>");
                    sb.append(dateStr);
                    sb.append("</span>");
                }
            }
            else {
                sb.append("&ensp;").append(dateStr);
            }
        }
        if (newLine) {
            if (alignRight) {
                sb.append("</span>");
            }
            else {
                sb.append("</span>");
            }
        }
        if (dateNewLine) {
            sb.append("<br/>");
        }
        return sb.toString().replaceAll("&nbsp;", "&ensp;");
    }
    
    private static V3xOrgMember getMember(final Long id, final OrgManager orgManager) {
        V3xOrgMember member = new V3xOrgMember();
        try {
            member = orgManager.getMemberById(id);
        }
        catch (final BusinessException e) {
            EdocOptionDisplayUtil.LOGGER.error((Object)"", (Throwable)e);
        }
        return member;
    }
    
    public static String optionToJs(final Map<String, Object> hs) {
        String key = "";
        final StringBuilder opinionsJs = new StringBuilder();
        opinionsJs.append("var opinions=[");
        final Iterator it = hs.keySet().iterator();
        boolean isFirst = true;
        String szTemp = null;
        while (it.hasNext()) {
            key = it.next();
            if (!"senderOpinionList".equals(key) && !"senderOpinionAttStr".equals(key)) {
                if ("commentAttachments".equals(key)) {
                    continue;
                }
                if (isFirst) {
                    isFirst = false;
                }
                else {
                    opinionsJs.append(",");
                }
                szTemp = hs.get(key).toString();
                szTemp = Strings.escapeJavascript(szTemp);
                opinionsJs.append("[\"").append(key).append("\",\"").append(szTemp).append("\"]");
            }
        }
        opinionsJs.append("];");
        opinionsJs.append("\r\n");
        String sendOpinionStr = "";
        final Object sendOpinionObj = hs.get("senderOpinionList");
        final Object opinionsAttachmentList = hs.get("commentAttachments");
        if (opinionsAttachmentList != null) {
            opinionsJs.append("var opinionsAttachmentList=" + JSONUtil.toJSONString(opinionsAttachmentList) + ";");
        }
        if (sendOpinionObj != null) {
            sendOpinionStr = sendOpinionObj.toString();
        }
        if ("[]".equals(sendOpinionStr)) {
            sendOpinionStr = "";
        }
        opinionsJs.append("var sendOpinionStr=\"" + sendOpinionStr + "\";");
        opinionsJs.append("var edocDetailURL=\"" + SystemEnvironment.getContextPath() + "/edocController.do\";");
        return opinionsJs.toString();
    }
    
    public static String getEdocOpinionPolicy(final Map<String, EdocOpinionModel> map) {
        Set set = null;
        String policy = null;
        if (map != null && !map.isEmpty()) {
            set = map.entrySet();
            if (set != null && !set.isEmpty()) {
                for (final Map.Entry entry : set) {
                    if (entry != null) {
                        policy = entry.getKey().toString();
                    }
                }
            }
        }
        return policy;
    }
    
    public static List<EdocOpinionBO> sortEdocOpinion(final List<EdocOpinion> opinions) {
        final List<EdocOpinionBO> opinionBOs = new ArrayList<EdocOpinionBO>();
        EdocOpinionBO edocOpinionBO = null;
        try {
            if (opinions != null) {
                for (int i = 0; i < opinions.size(); ++i) {
                    edocOpinionBO = new EdocOpinionBO();
                    BeanUtils.copyProperties((Object)edocOpinionBO, (Object)opinions.get(i));
                    opinionBOs.add(edocOpinionBO);
                }
            }
        }
        catch (final Exception ex) {}
        return opinionBOs;
    }
    
    public static String getAffairReturnState(final Map<String, EdocOpinionModel> map, final String policy, final CtpAffair currentAffair) throws BusinessException {
        List<EdocOpinion> opinions = null;
        EdocOpinionModel edocOpinionModel = null;
        if (map != null) {
            edocOpinionModel = map.get(policy);
        }
        if (edocOpinionModel != null) {
            opinions = edocOpinionModel.getOpinions();
        }
        return getAffairReturnState(opinions, currentAffair);
    }
    
    public static String getAffairReturnState(final List<EdocOpinion> opinions, final CtpAffair currentAffair) throws BusinessException {
        final List<EdocOpinionBO> opinionBOs = sortEdocOpinion(opinions);
        final AffairManager affairManager = (AffairManager)AppContext.getBean("affairManager");
        String affairState = "";
        if (opinionBOs != null) {
            EdocOpinionBO edocOpinion = null;
            CtpAffair affair1 = null;
            CtpAffair affair2 = null;
            final int count = opinionBOs.size();
            final long currentUserId = AppContext.getCurrentUser().getId();
            for (int i = count - 1; i >= 0; --i) {
                edocOpinion = opinionBOs.get(i);
                affair1 = affairManager.get(Long.valueOf(edocOpinion.getAffairId()));
                if (affair1 != null) {
                    final boolean isCurrentAffair = affair1 != null && affair1.getActivityId() != null && currentAffair.getActivityId() != null && affair1.getActivityId().equals(currentAffair.getActivityId()) && affair1.getMemberId() == currentUserId;
                    final boolean isCurrentAffairState = affair1.getState() == StateEnum.col_pending.key() && (affair1.getSubState() == SubStateEnum.col_pending_ZCDB.key() || affair1.getSubState() == SubStateEnum.col_pending_read.key());
                    if (isCurrentAffair && !isCurrentAffairState) {
                        affair2 = affair1;
                        break;
                    }
                }
            }
            if (affair2 != null) {
                affairState = String.valueOf(affair2.getState());
            }
        }
        return affairState;
    }
    
    private static String subLargerGuanlanWendang(final String str) {
        final int begin = str.indexOf("style='font-size:12px'>");
        final int end = str.indexOf("</a>");
        if (begin == -1 && end == -1) {
            return str;
        }
        String wname = str.substring(begin, end).replace("style='font-size:12px'>", "");
        final StringBuilder sb = new StringBuilder();
        if (wname.length() < 30) {
            return str;
        }
        sb.append(str.substring(0, begin));
        sb.append("style='font-size:12px'>");
        wname = wname.replace("&nbsp;", " ");
        if (wname.length() > 30) {
            wname = wname.substring(0, 30);
        }
        sb.append(wname);
        sb.append("......");
        sb.append(str.substring(end));
        return sb.toString();
    }
    
    private static String getOpinionImgUserNameForGZZB(final Long userId, final String proxyName, final OrgManager orgManager) {
        String doUserName = "";
        try {
            final V3xOrgMember member = orgManager.getMemberById(userId);
            doUserName = member.getName();
            if (member.getIsAdmin()) {
                doUserName = "";
            }
            else {
                final SignetManager signetManager = (SignetManager)AppContext.getBean("signetManager");
                final List<V3xSignet> signets = signetManager.findSignetByMemberId(userId);
                V3xSignet ssi = null;
                if (signets != null && signets.size() > 0) {
                    for (int i = 0; i < signets.size(); ++i) {
                        if (signets.get(i).getMarkType().equals(0)) {
                            ssi = signets.get(i);
                            break;
                        }
                    }
                }
                final String namePath = SystemEnvironment.getContextPath() + "/apps_res/edoc/images/signets/";
                if (ssi != null) {
                    final byte[] b = ssi.getMarkBodyByte();
                    String path = SystemProperties.getInstance().getProperty("A8.base.folder") + "/";
                    path += "../ApacheJetspeed/webapps";
                    path += namePath;
                    final CtpLocalFile file = new CtpLocalFile(path);
                    if (!file.exists()) {
                        file.mkdirs();
                    }
                    path = path + userId + ssi.getImgType();
                    writeFile(path, b);
                    final String spath = namePath + userId + ssi.getImgType() + "?r=" + System.currentTimeMillis();
                    doUserName = "<img name='signimg' src=" + spath + " class='color_blue'  onclick='javascript:showV3XMemberCard(\"" + userId + "\")'></img>";
                }
                else {
                    doUserName = "<span class='color_blue' onclick='javascript:showV3XMemberCard(\"" + userId + "\")'>" + doUserName + "</span>";
                }
            }
            if (!Strings.isBlank(proxyName)) {
                doUserName += ResourceBundleUtil.getString("com.seeyon.v3x.edoc.resources.i18n.EdocResource", "edoc.opinion.proxy", new Object[] { proxyName });
            }
        }
        catch (final Exception e) {
            EdocOptionDisplayUtil.LOGGER.error((Object)e.getMessage(), (Throwable)e);
        }
        doUserName = "<br>&nbsp;&nbsp;&nbsp;&nbsp;" + doUserName;
        return doUserName;
    }
    
    private static String getIconClass(final String type) {
        if ("txt".equals(type)) {
            return "see-icon-v5-form-ic-txt-fill";
        }
        if ("jpg".equals(type) || "png".equals(type) || "icon".equals(type) || "gif".equals(type)) {
            return "see-icon-v5-form-ic-image-fill";
        }
        if ("doc".equals(type) || "docx".equals(type)) {
            return "see-icon-v5-form-ic-doc-fill";
        }
        if ("xls".equals(type) || "xlsx".equals(type)) {
            return "see-icon-v5-form-ic-xls-fill";
        }
        if ("ppt".equals(type) || "pptx".equals(type)) {
            return "see-icon-v5-form-ic-ppt-fill";
        }
        if ("wps".equals(type)) {
            return "see-icon-v5-form-ic-wps-fill";
        }
        if ("vsd".equals(type)) {
            return "see-icon-v5-form-ic-vsd-fill";
        }
        if ("pdf".equals(type)) {
            return "see-icon-v5-form-ic-pdf-fill";
        }
        if ("et".equals(type)) {
            return "see-icon-v5-form-ic-et-fill";
        }
        if ("htm".equals(type) || "html".equals(type) || "sht".equals(type) || "shtm".equals(type) || "shtml".equals(type) || "asp".equals(type) || "aspx".equals(type) || "php".equals(type) || "jsp".equals(type)) {
            return "see-icon-v5-form-ic-html-fill";
        }
        if ("mp3".equals(type)) {
            return "see-icon-v5-form-ic-mp3-fill";
        }
        if ("avi".equals(type) || "mp4".equals(type) || "wmv".equals(type) || "rm".equals(type) || "rmvb".equals(type) || "mpg".equals(type) || "mkv".equals(type) || "flv".equals(type)) {
            return "see-icon-v5-form-ic-mp4-fill";
        }
        if ("wma".equals(type) || "wav".equals(type) || "amr".equals(type) || "ACT".equals(type) || "ava".equals(type)) {
            return "see-icon-v5-form-ic-voice-fill";
        }
        if ("zip".equals(type) || "rar".equals(type) || "jar".equals(type) || "tar".equals(type) || "7z".equals(type)) {
            return "see-icon-v5-form-ic-zip-fill";
        }
        if ("collaboration".equals(type)) {
            return "see-icon-v5-form-ic-col-fill";
        }
        if ("edoc".equals(type)) {
            return "see-icon-v5-form-ic-offdoc-fill";
        }
        if ("km".equals(type)) {
            return "see-icon-v5-form-relation-doc";
        }
        if ("exe".equals(type)) {
            return "cmp-icon-document exe";
        }
        if ("ofd".equals(type)) {
            return "cmp-icon-document ofd";
        }
        return "see-icon-v5-form-ic-unknown-fill";
    }
    
    public static void writeFile(final String url, final byte[] b) {
        final CtpLocalFile file = new CtpLocalFile(url);
        BufferedOutputStream stream = null;
        FileOutputStream fstream = null;
        try {
            if (file.exists()) {
                file.delete();
            }
            file.createNewFile();
            fstream = new FileOutputStream((File)file);
            stream = new BufferedOutputStream(fstream);
            stream.write(b);
        }
        catch (final IOException e) {
            EdocOptionDisplayUtil.LOGGER.error((Object)e);
            try {
                if (stream != null) {
                    stream.close();
                }
            }
            catch (final IOException e) {
                EdocOptionDisplayUtil.LOGGER.error((Object)e);
            }
            try {
                if (fstream != null) {
                    fstream.close();
                }
            }
            catch (final IOException e) {
                EdocOptionDisplayUtil.LOGGER.error((Object)e);
            }
        }
        finally {
            try {
                if (stream != null) {
                    stream.close();
                }
            }
            catch (final IOException e2) {
                EdocOptionDisplayUtil.LOGGER.error((Object)e2);
            }
            try {
                if (fstream != null) {
                    fstream.close();
                }
            }
            catch (final IOException e2) {
                EdocOptionDisplayUtil.LOGGER.error((Object)e2);
            }
        }
    }
    
    public static String getOpinionUserNameForM3(final V3xOrgMember member, final FormOpinionConfig displayConfig, final EdocOpinion edocOpinion, final boolean hasHandWriteSignature, final List<V3xHtmDocumentSignature> edocOpinionSigns, final String proxyName) {
        String doUserName = "";
        try {
            doUserName = member.getName();
            final String postInfo = edocOpinion.getPostInfo();
            Long accountId = null;
            if (Strings.isNotBlank(postInfo)) {
                final String[] postInfos = postInfo.split("\\|");
                if (postInfos.length > 2) {
                    final String accountIdStringType = postInfos[0];
                    accountId = Long.parseLong(accountIdStringType);
                }
            }
            if (accountId == null) {
                accountId = member.getOrgAccountId();
            }
            if (edocOpinion.isBound() && EdocOpinionDisplayEnum.OpinionShowNameTypeEnum.SIGN.getValue().equals(displayConfig.getShowNameType())) {
                final List<V3xHtmDocumentSignature> signatureList = new ArrayList<V3xHtmDocumentSignature>();
                if (Strings.isNotEmpty((Collection)edocOpinionSigns)) {
                    for (final V3xHtmDocumentSignature sign : edocOpinionSigns) {
                        if (sign.getAffairId() != null && Strings.equals((Object)edocOpinion.getAffairId(), (Object)sign.getAffairId())) {
                            signatureList.add(sign);
                        }
                    }
                }
                if (Strings.isNotEmpty((Collection)signatureList)) {
                    final GovdocSignetManager govdocSignetManager = (GovdocSignetManager)AppContext.getBean("govdocSignetManager");
                    final List<V3xSignet> signetList = govdocSignetManager.findSignetByMemberId(Long.valueOf(edocOpinion.getCreateUserId()));
                    V3xSignet v3xSignet = null;
                    if (signetList != null && !signetList.isEmpty()) {
                        final Integer signType = new Integer(0);
                        for (final V3xSignet signTemp : signetList) {
                            if (signType.equals(signTemp.getMarkType())) {
                                if (accountId == null) {
                                    v3xSignet = signTemp;
                                    break;
                                }
                                if (signTemp.getOrgAccountId() == (long)accountId) {
                                    v3xSignet = signTemp;
                                    break;
                                }
                                continue;
                            }
                        }
                    }
                    if (v3xSignet != null) {
                        doUserName = "id=" + v3xSignet.getId();
                    }
                }
            }
            if (member.getIsAdmin()) {
                doUserName = "";
            }
            if (displayConfig.isHideInscriber() && hasHandWriteSignature) {
                doUserName = "";
            }
            if (!Strings.isBlank(proxyName) && !doUserName.startsWith("id=")) {
                doUserName += ResourceBundleUtil.getString("com.seeyon.v3x.edoc.resources.i18n.EdocResource", "edoc.opinion.proxy", new Object[] { proxyName });
            }
        }
        catch (final Exception e) {
            EdocOptionDisplayUtil.LOGGER.error((Object)"取公文单显示的时候的人名 抛出异常", (Throwable)e);
        }
        return doUserName;
    }
    
    public static List<Object> getGovdocOpinionsForM3TaoHong(final EdocSummary summary) throws BusinessException {
        final FormApi4Cap3 formApi4Cap3 = (FormApi4Cap3)AppContext.getBean("formApi4Cap3");
        final FormOptionExtendManager formOptionExtendManager = (FormOptionExtendManager)AppContext.getBean("formOptionExtendManager");
        final FormOptionSortManager formOptionSortManager = (FormOptionSortManager)AppContext.getBean("formOptionSortManager");
        final V3xHtmDocumentSignatManager v3xHtmDocumentSignatManager = (V3xHtmDocumentSignatManager)AppContext.getBean("v3xHtmDocumentSignatManager");
        final GovdocCommentManager govdocCommentManager = (GovdocCommentManager)AppContext.getBean("govdocCommentManager");
        final OrgManager orgManager = (OrgManager)AppContext.getBean("orgManager");
        final AffairManager affairManager = (AffairManager)AppContext.getBean("affairManager");
        final FormOpinionConfig displayConfig = getFormOpinionConfig(summary, formOptionExtendManager);
        final Map<String, EdocOpinionModel> filedNameMapOpinions = formOptionSortManager.getGovdocOpinion((long)summary.getFormAppid(), summary, displayConfig);
        final List<V3xHtmDocumentSignature> handWrites = v3xHtmDocumentSignatManager.findBySummaryIdAndType(summary.getId(), V3xHtmSignatureEnum.HTML_SIGNATURE_DOCUMENT.getKey());
        Map<Long, V3xHtmDocumentSignature> affairIdMapHandWriteSign = null;
        if (Strings.isNotEmpty((Collection)handWrites)) {
            affairIdMapHandWriteSign = handWrites.stream().collect(Collectors.toMap((Function<? super Object, ? extends Long>)V3xHtmDocumentSignature::getAffairId, signature -> signature, (a, b) -> b));
        }
        final List<V3xHtmDocumentSignature> edocOpinionSigns = v3xHtmDocumentSignatManager.findBySummaryIdAndType(summary.getId(), V3xHtmSignatureEnum.HTML_SIGNATURE_EDOC_FLOW_INSCRIBE.getKey());
        final int backOpinionType = displayConfig.getBackOpinionType();
        Map<Long, List<Comment>> commentMap = new HashMap<Long, List<Comment>>();
        final List<Comment> commentList = govdocCommentManager.getCommentList(ModuleType.edoc, summary.getId());
        if (Strings.isNotEmpty((Collection)commentList)) {
            commentMap = commentList.stream().filter(item -> backOpinionType != 1 || !"common.toolbar.stepBack.label".equals(item.getExtAtt3())).collect((Collector<? super Object, ?, Map<Long, List<Comment>>>)Collectors.groupingBy((Function<? super Object, ? extends Long>)Comment::getAffairId));
        }
        final boolean showZcdb = !FormOpinionConfig.checkBoolean(displayConfig.getZcdbOptionType());
        final FormBean form = formApi4Cap3.getForm((long)summary.getFormAppid());
        final Map<String, String> fieldNameMapElement = (Map<String, String>)form.getAllFieldBeans().stream().filter(fieldBean -> Strings.isNotBlank(fieldBean.getMappingField())).collect(Collectors.toMap((Function<? super Object, ?>)FormFieldBean::getName, (Function<? super Object, ?>)FormFieldBean::getMappingField, (a, b) -> b));
        final List<List<String>> rows = new ArrayList<List<String>>();
        final List<EdocOpinion> senderOpinions = new ArrayList<EdocOpinion>();
        for (final Map.Entry<String, EdocOpinionModel> entry : filedNameMapOpinions.entrySet()) {
            final String fieldName = entry.getKey();
            final EdocOpinionModel model = entry.getValue();
            final List<EdocOpinion> edocOpinionList = model.getOpinions();
            final List<String> columns = new ArrayList<String>();
            columns.add(fieldNameMapElement.get(fieldName));
            for (final EdocOpinion opinion : edocOpinionList) {
                if (Strings.equals((Object)EdocOpinion.OpinionType.provisionalOpinoin.ordinal(), (Object)opinion.getOpinionType()) && !showZcdb) {
                    continue;
                }
                if (Strings.equals((Object)EdocOpinion.OpinionType.draftOpinion.ordinal(), (Object)opinion.getOpinionType())) {
                    continue;
                }
                V3xOrgMember member = null;
                try {
                    member = orgManager.getMemberById(Long.valueOf(opinion.getCreateUserId()));
                    if (member.getIsAdmin()) {
                        continue;
                    }
                }
                catch (final BusinessException e) {
                    EdocOptionDisplayUtil.LOGGER.error((Object)"", (Throwable)e);
                }
                final Comment comment = getComment(commentMap, opinion);
                if (comment == null) {
                    EdocOptionDisplayUtil.LOGGER.error((Object)("文单区意见未找到对应的意见区意见，opinion.id=" + opinion.getId() + ", affairId=" + opinion.getAffairId()));
                }
                else {
                    if (Objects.nonNull(comment.getCreateDate())) {
                        opinion.setCreateTime(new Timestamp(comment.getCreateDate().getTime()));
                    }
                    final String attitude = getAttitude(displayConfig, opinion, comment);
                    if (Strings.isNotBlank(attitude) && !Strings.equals((Object)"report", (Object)opinion.getPolicy())) {
                        final String attitudeStr = "【" + attitude + "】";
                        columns.add(attitudeStr);
                    }
                    String content = opinion.getContent();
                    if (!FormOpinionConfig.checkBoolean(displayConfig.getComment())) {
                        content = "";
                    }
                    columns.add(content);
                    final boolean newLine = displayConfig.isInscriberNewLine();
                    if (newLine) {
                        columns.add("\r\n");
                    }
                    else if (Strings.isNotBlank(content) && (displayConfig.isShowDept() || displayConfig.isShowUnit())) {
                        columns.add("  ");
                    }
                    boolean isDisplay = true;
                    if (displayConfig.isHideInscriber()) {
                        try {
                            final CtpAffair affair = affairManager.get(Long.valueOf(opinion.getAffairId()));
                            if (affair != null && affair.getSubState() == SubStateEnum.col_done_stepStop.key()) {
                                isDisplay = false;
                            }
                        }
                        catch (final BusinessException e2) {
                            EdocOptionDisplayUtil.LOGGER.error((Object)"获取affair错误", (Throwable)e2);
                        }
                    }
                    final boolean hasHandWriteSignature = affairIdMapHandWriteSign != null && affairIdMapHandWriteSign.containsKey(opinion.getAffairId());
                    final String userName = getOpinionUserNameForM3(member, displayConfig, opinion, hasHandWriteSignature, edocOpinionSigns, opinion.getProxyName());
                    if (displayConfig.isShowUnit() && (!displayConfig.isHideInscriber() || !hasHandWriteSignature) && isDisplay) {
                        if (newLine) {
                            columns.add(opinion.getAccountName());
                        }
                        else {
                            columns.add(" ");
                            columns.add(opinion.getAccountName());
                        }
                    }
                    if (displayConfig.isShowDept() && (!displayConfig.isHideInscriber() || !hasHandWriteSignature) && isDisplay) {
                        if (newLine && !displayConfig.isShowUnit()) {
                            columns.add(opinion.getDepartmentName());
                        }
                        else {
                            columns.add(" ");
                            columns.add(opinion.getDepartmentName());
                        }
                    }
                    final boolean dateNewLine = FormOpinionConfig.checkBoolean(displayConfig.getDateNewLine());
                    if (dateNewLine) {
                        columns.add(" ");
                    }
                    if (displayConfig.isShowName() && (!displayConfig.isHideInscriber() || !hasHandWriteSignature) && isDisplay) {
                        columns.add(" ");
                        columns.add(userName);
                    }
                    final String dateStr = getDateStr(displayConfig, opinion);
                    if (Strings.isNotBlank(dateStr)) {
                        if (dateNewLine) {
                            columns.add("\r\n");
                            columns.add(dateStr);
                        }
                        else {
                            columns.add(" ");
                            columns.add(dateStr);
                        }
                    }
                    columns.add("\r\n");
                    List<Attachment> tempAtts = null;
                    if (null != opinion.getPolicy() && opinion.getPolicy().equals("feedback")) {
                        final Long subOpinionId = opinion.getSubOpinionId();
                        if (subOpinionId != null) {
                            tempAtts = GovdocHelper.getOpinionAttachmentsNotRelationDoc((long)opinion.getSubEdocId(), (long)subOpinionId);
                        }
                    }
                    else {
                        tempAtts = opinion.getOpinionAttachments();
                    }
                    if (tempAtts != null && displayConfig.isShowAtt()) {
                        final StringBuilder fileName = new StringBuilder();
                        for (final Attachment att : tempAtts) {
                            columns.add("\r\n");
                            fileName.setLength();
                            fileName.append(att.getFilename());
                            if (att.getSize() > 0L && att.getType() == 0) {
                                fileName.append("(").append(Strings.formatFileSize((long)att.getSize(), true)).append(")");
                            }
                            columns.add(fileName.toString());
                            columns.add(" ");
                        }
                        columns.add(" ");
                    }
                    columns.add("\n");
                    if (hasHandWriteSignature) {
                        final V3xHtmDocumentSignature handWrite = affairIdMapHandWriteSign.get(opinion.getAffairId());
                        if (handWrite != null) {
                            columns.add("method=writeGIF&RECORDID=" + handWrite.getSummaryId() + "&FIELDNAME=" + handWrite.getFieldName() + "&isNewImg=true&affairId=" + handWrite.getAffairId());
                        }
                    }
                    if (Strings.equals((Object)"senderOpinion", (Object)fieldName)) {
                        senderOpinions.add(opinion);
                    }
                    rows.add(columns);
                }
            }
        }
        final List<Object> result = new ArrayList<Object>();
        result.add(rows);
        result.add(senderOpinions);
        return result;
    }
    
    private static String getDateStr(final FormOpinionConfig displayConfig, final EdocOpinion opinion) {
        String dateStr = "";
        if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATETIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                final Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format"));
            }
            else {
                dateStr = Datetimes.formatDatetimeWithoutSecond((Date)opinion.getCreateTime());
            }
        }
        else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATE.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                final Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format1"));
            }
            else {
                dateStr = Datetimes.formatDate((Date)opinion.getCreateTime());
            }
        }
        else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.TIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                final Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format3"));
            }
            else {
                dateStr = Datetimes.format((Date)opinion.getCreateTime(), " HH:mm");
            }
        }
        return dateStr;
    }
    
    private static String getAttitude(final FormOpinionConfig displayConfig, final EdocOpinion opinion, final Comment comment) {
        String tempAttitude = "";
        if (opinion.getAttribute() == 1) {
            tempAttitude = "haveRead";
        }
        else if (opinion.getAttribute() == 2) {
            tempAttitude = "agree";
        }
        else if (opinion.getAttribute() == 3) {
            tempAttitude = "disagree";
        }
        String attitude = "";
        if (tempAttitude.equals((comment.getExtAtt4() == null) ? "" : comment.getExtAtt4())) {
            attitude = comment.getExtAtt1I18n();
        }
        if (Strings.isNotBlank(comment.getExtAtt1())) {
            attitude = comment.getExtAtt1I18n();
        }
        if (!FormOpinionConfig.checkBoolean(displayConfig.getAttitude())) {
            attitude = "";
        }
        return attitude;
    }
    
    private static Comment getComment(final Map<Long, List<Comment>> commentMap, final EdocOpinion opinion) {
        Comment comment = null;
        final List<Comment> comments = commentMap.get(opinion.getAffairId());
        if (Strings.isNotEmpty((Collection)comments)) {
            if (comments.size() == 1) {
                comment = comments.get(0);
            }
            else {
                for (final Comment tempComment : comments) {
                    if (tempComment.getCreateDate().equals(opinion.getCreateTime())) {
                        comment = tempComment;
                        break;
                    }
                }
                if (comment == null) {
                    final Date beforeTwoSecond = Datetimes.addSecond((Date)opinion.getCreateTime(), -3);
                    final Date afterTwoSecond = Datetimes.addSecond((Date)opinion.getCreateTime(), 3);
                    for (final Comment tempComment2 : comments) {
                        if (Datetimes.between(tempComment2.getCreateDate(), beforeTwoSecond, afterTwoSecond, false)) {
                            comment = tempComment2;
                            break;
                        }
                    }
                }
                if (comment == null) {
                    comment = comments.get(0);
                }
            }
        }
        return comment;
    }
    
    private static FormOpinionConfig getFormOpinionConfig(final EdocSummary summary, final FormOptionExtendManager formOptionExtendManager) {
        final FormOptionExtend govdocFormExtend = formOptionExtendManager.findByFormId((long)summary.getFormAppid());
        FormOpinionConfig displayConfig = null;
        if (null != govdocFormExtend) {
            displayConfig = (FormOpinionConfig)JSONUtil.parseJSONString(govdocFormExtend.getOptionFormatSet(), (Class)FormOpinionConfig.class);
            if (!govdocFormExtend.getOptionFormatSet().contains("showAtt")) {
                displayConfig.setShowAtt(true);
            }
        }
        if (displayConfig == null) {
            displayConfig = new FormOpinionConfig();
        }
        return displayConfig;
    }
    
    static {
        LOGGER = CtpLogFactory.getLog((Class)EdocOptionDisplayUtil.class);
    }
}
